@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """Structures from the Boyd-Woo database and labels from Moosavi et al."""
 import os
-from typing import Iterable, Optional, Tuple
+from typing import Collection, Optional, Tuple
 
 import numpy as np
 import pandas as pd
@@ -98,7 +98,7 @@ class BWDataset(AbstractStructureDataset):
         self,
         version: str = "v0.0.1",
         drop_graph_duplicates: bool = True,
-        subset: Optional[Iterable[int]] = None,
+        subset: Optional[Collection[int]] = None,
     ):
         """Construct an instance of the CoRE dataset.
 
@@ -107,7 +107,7 @@ class BWDataset(AbstractStructureDataset):
                 Defaults to "v0.0.1".
             drop_graph_duplicates (bool): If True, keep only one structure
                 per decorated graph hash. Defaults to True.
-            subset (Iterable[int], optional): indices of the structures to include.
+            subset (Collection[int], optional): indices of the structures to include.
                 Defaults to None.
 
         Raises:
@@ -162,11 +162,11 @@ class BWDataset(AbstractStructureDataset):
         self._featurenames = (c for c in self._df.columns if c.startswith("features."))
         self._infonames = (c for c in self._df.columns if c.startswith("info."))
 
-    def get_subset(self, indices: Iterable[int]) -> "AbstractStructureDataset":
+    def get_subset(self, indices: Collection[int]) -> "AbstractStructureDataset":
         """Get a subset of the dataset.
 
         Args:
-            indices (Iterable[int]): indices of the structures to include.
+            indices (Collection[int]): indices of the structures to include.
 
         Returns:
             AbstractStructureDataset: a new dataset containing only the structures
@@ -190,7 +190,7 @@ class BWDataset(AbstractStructureDataset):
     def available_labels(self) -> Tuple[str]:
         return self._labelnames
 
-    def get_labels(self, idx: Iterable[int], labelnames: Iterable[str] = None) -> np.ndarray:
+    def get_labels(self, idx: Collection[int], labelnames: Collection[str] = None) -> np.ndarray:
         labelnames = labelnames if labelnames is not None else self._labelnames
         return self._df.iloc[idx][list(labelnames)].values
 
