@@ -18,7 +18,7 @@ def get_eqeq_charges(structure: IStructure) -> Tuple[str, List[float]]:
     with open(os.devnull, "w") as devnull, contextlib.redirect_stdout(devnull), NamedTemporaryFile(
         "w", suffix=".cif"
     ) as f:
-        structure.to("cif", f.name)
+        structure.to(filename=f.name, fmt="cif")
         charges = run_on_cif(f.name)
 
     atoms = AseAtomsAdaptor().get_atoms(structure)
